@@ -1,3 +1,18 @@
+/* Copyright 1999-2004 The Apache Software Foundation
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+   	http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+*/
+
 #ifndef _APACHE_REQUEST_H
 
 #define _APACHE_REQUEST_H
@@ -60,19 +75,19 @@ struct ApacheUpload {
 };
 
 #ifndef strEQ
-#define strEQ(s1,s2) (!strcmp(s1,s2))
+#define strEQ(s1,s2) (!strcmp((s1),(s2)))
 #endif
 
 #ifndef strEQN
-#define strEQN(s1,s2,n) (!strncmp(s1,s2,n))
+#define strEQN(s1,s2,n) (!strncmp((s1),(s2),(n)))
 #endif
 
 #ifndef strcaseEQ
-#define strcaseEQ(s1,s2) (!strcasecmp(s1,s2))
+#define strcaseEQ(s1,s2) (!strcasecmp((s1),(s2)))
 #endif
 
 #ifndef strncaseEQ
-#define strncaseEQ(s1,s2,n) (!strncasecmp(s1,s2,n))
+#define strncaseEQ(s1,s2,n) (!strncasecmp((s1),(s2),(n)))
 #endif
 
 #define DEFAULT_TABLE_NELTS 10
@@ -97,7 +112,7 @@ array_header *ApacheRequest_params(ApacheRequest *req, const char *key);
 char *ApacheRequest_params_as_string(ApacheRequest *req, const char *key);
 int ApacheRequest___parse(ApacheRequest *req);
 #define ApacheRequest_parse(req) \
-    (req->status = req->parsed ? req->status : ApacheRequest___parse(req)) 
+    ((req)->status = (req)->parsed ? (req)->status : ApacheRequest___parse(req)) 
 table *ApacheRequest_query_params(ApacheRequest *req, ap_pool *p);
 table *ApacheRequest_post_params(ApacheRequest *req, ap_pool *p);
 
@@ -106,20 +121,20 @@ ApacheUpload *ApacheUpload_new(ApacheRequest *req);
 ApacheUpload *ApacheUpload_find(ApacheUpload *upload, char *name);
 
 #define ApacheRequest_upload(req) \
-    ((req->parsed || (ApacheRequest_parse(req) == OK)) ? req->upload : NULL)
+    (((req)->parsed || (ApacheRequest_parse(req) == OK)) ? (req)->upload : NULL)
 
-#define ApacheUpload_FILE(upload) (upload->fp)
+#define ApacheUpload_FILE(upload) ((upload)->fp)
 
-#define ApacheUpload_size(upload) (upload->size)
+#define ApacheUpload_size(upload) ((upload)->size)
 
 #define ApacheUpload_info(upload, key) \
-ap_table_get(upload->info, key)
+ap_table_get((upload)->info, (key))
 
 #define ApacheUpload_type(upload) \
-ApacheUpload_info(upload, "Content-Type")
+ApacheUpload_info((upload), "Content-Type")
 
-#define ApacheRequest_set_post_max(req, max) (req->post_max = max)
-#define ApacheRequest_set_temp_dir(req, dir) (req->temp_dir = dir)
+#define ApacheRequest_set_post_max(req, max) ((req)->post_max = (max))
+#define ApacheRequest_set_temp_dir(req, dir) ((req)->temp_dir = (dir))
 
 char *ApacheUtil_expires(pool *p, char *time_str, int type);
 #define EXPIRES_HTTP   1
@@ -133,7 +148,7 @@ char *ApacheRequest_expires(ApacheRequest *req, char *time_str);
 #define REQ_ERROR APLOG_MARK, APLOG_NOERRNO|APLOG_ERR, req->r
 
 #ifdef REQDEBUG
-#define REQ_DEBUG(a) a
+#define REQ_DEBUG(a) (a)
 #else
 #define REQ_DEBUG(a)
 #endif
